'use strict';

var fs = require('fs');
var path = require('path');
var appRoot = __dirname.split('node_modules')[0];

module.exports = {
    config: function(options, cwd) {
        var webpack = this.webpack;
        var config = this.config;

        config.context = path.join(appRoot, 'src');
        config.entry = {
            'bundle.js': ['../ssr/client/index.js']
        };
        config.output.local = {
            path: path.join(appRoot, 'prd'),
            filename: '[name][ext]',
            chunkFilename: '[name]-chunk[ext]',
            publicPath: '/prd/'
        };
        config.output.prd = {
            path: path.join(appRoot, 'prd'),
            filename: '[name]@[chunkhash][ext]',
            chunkFilename: '[name]-chunk@[chunkhash][ext]',
            publicPath: '/prd/'
        };
        config.module.loaders.push(
            {
                test: /\.(js|jsx)$/,
                loader: require.resolve('babel-loader'),
                exclude: [/node_modules/],
                query: {
                    "cacheDirectory": true,
                    "presets": [
                        "react", ["env", {
                            "targets": {
                                "node": "current",
                                "browsers": [
                                    "> 1%",
                                    "last 3 versions",
                                    "ie 9"
                                ]
                            },
                            "useBuiltIns": "usage"
                        }]
                    ],
                    "plugins": [
                        "transform-decorators-legacy",
                        "transform-class-properties",
                        "transform-async-to-generator",
                        "transform-object-rest-spread"
                    ]
                }
            }
        );
        config.plugins.push(
            new webpack.DefinePlugin({
                "process.env": {
                    BROWSER: JSON.stringify(true),
                    NODE_ENV: JSON.stringify(this.env === 'prd' ? 'production' : 'development')
                }
            })
        );
        if(config.resolve.extensions.indexOf('.jsx') === -1) {
            config.resolve.extensions.push('.jsx');
        }

        this.commands.push({
            name: 'start',
            module: require('./commands/start.js')
        }, {
            name: 'setup',
            module: require('./commands/setup.js')
        });
    }
}
